@@ -2,7 +2,7 @@ try:
     import napari
     from qtpy.QtCore import QTimer
     from qtpy.QtWidgets import QTableWidget, QHBoxLayout, QTableWidgetItem, QWidget, QGridLayout, QPushButton, QFileDialog
-except ModuleNotFoundError as e:
+except Exception as e:
     import warnings
     warnings.warn(str(e))
     class QWidget:
@@ -76,9 +76,13 @@ class TableWidget(QWidget):
             print("Selected column", selected_column)
             if selected_column is not None:
                 if isinstance(self._layer, napari.layers.Labels):
-                    from ._parametric_images import visualize_measurement_on_labels
-                    new_layer = self._viewer.add_image(visualize_measurement_on_labels(self._layer, selected_column, self._viewer),
-                                           name=selected_column + " in " + self._layer.name)
+                    from ._parametric_images import visualize_measurement_on_labels, map_measurements_on_labels
+                    new_layer = self._viewer.add_image( map_measurements_on_labels(self._layer, selected_column, self._viewer) ,
+                                                        name=selected_column + " in " + self._layer.name ,
+                                                        affine=self._layer.affine ,
+                                                        scale=self._layer.scale,
+                                                        rotate=self._layer.rotate
+                                                        )
                     new_layer.contrast_limits = [np.min(self._table[selected_column]), np.max(self._table[selected_column])]
                     new_layer.colormap = "jet"
                 elif isinstance(self._layer, napari.layers.Points):
@@ -88,7 +92,10 @@ class TableWidget(QWidget):
                                                         face_color=selected_column,
                                                         face_colormap="jet",
                                                         size=self._layer.size,
-                                                        name=selected_column + " in " + self._layer.name
+                                                        name=selected_column + " in " + self._layer.name,
+                                                        affine=self._layer.affine,
+                                                        scale=self._layer.scale,
+                                                        rotate=self._layer.rotate
                                                         )
                     new_layer.contrast_limits = [np.min(self._table[selected_column]), np.max(self._table[selected_column])]
 
@@ -239,7 +246,7 @@ class TableWidget(QWidget):
 
 
 @register_function(menu="Measurement > Show table (nsr)")
-def add_table(labels_layer: "napari.layers.Layer", viewer: "napari.Viewer") -> TableWidget:
+def add_table(labels_layer: "napari.layers.Layer", viewer: "napari.Viewer", tabify: bool = False) -> TableWidget:
     """
     Add a table to a viewer and return the table widget. The table will show the `properties` of the given layer.
     """
@@ -247,7 +254,7 @@ def add_table(labels_layer: "napari.layers.Layer", viewer: "napari.Viewer") -> T
     if dock_widget is None:
         dock_widget = TableWidget(labels_layer, viewer)
         # add widget to napari
-        viewer.window.add_dock_widget(dock_widget, area='right', name="Properties of " + labels_layer.name)
+        viewer.window.add_dock_widget(dock_widget, area='right', name="Properties of " + labels_layer.name, tabify = tabify)
     else:
         dock_widget.set_content(labels_layer.properties)
         if not dock_widget.parent().isVisible():
